@@ -6,7 +6,7 @@ from os.path import join as opj
 from os.path import dirname
 from biobb_structure_checking.param_input import Dialog
 
-VERSION = '3.9.8'
+VERSION = '3.9.11'
 
 # Default locations and settings
 DATA_DIR_DEFAULT_PATH = 'dat'
@@ -74,13 +74,13 @@ CMD_LINE = argparse.ArgumentParser(
 CMD_LINE.add_argument(
     '-i', '--input',
     dest='input_structure_path',
-    help='Input structure. Formats PDB|mmCIF. Remote pdb:{pdbid}'
+    help='Input structure. Formats pdb(qt)|pqr|cif. Remote pdb:{pdbid}'
 )
 
 CMD_LINE.add_argument(
     '--file_format',
     dest='file_format',
-    help='Format for retrieving structures (default=mmCif|pdb|xml)'
+    help='Format for retrieving structures (default=cif|pdb|xml)'
 )
 
 CMD_LINE.add_argument(
@@ -135,6 +135,13 @@ CMD_LINE.add_argument(
     choices=['pdb', 'pdbqt', 'pqr', 'cmip']
 )
 
+CMD_LINE.add_argument(
+    '--keep_canonical_resnames',
+    action="store_true",
+    dest='keep_canonical',
+    help='Keep canonical names for ionized residues in output files'
+)
+
 CMD_LINE.add_argument(
     '--rename_terms',
     action="store_true",
@@ -285,7 +292,7 @@ DIALOGS.add_option('backbone', '--fix_atoms', 'fix_atoms',\
 DIALOGS.add_option('backbone', '--fix_chain', 'fix_chain',\
     'Fixes missing main chain segments (All | None | List)')
 DIALOGS.add_option('backbone', '--add_caps', 'add_caps',\
-    'Adds ACE and NME caps to missing main chain segments (All | None)')
+    'Adds ACE and NME caps to missing main chain segments (All | None | Breaks | Terms)')
 DIALOGS.add_option('backbone', '--no_check_clashes', 'no_check_clashes',\
     'Do not check for new clashes', 'bool')
 DIALOGS.add_option('backbone', '--extra_gap', 'extra_gap',\
