@@ -1529,7 +1529,7 @@ class StructureChecking():
                         form = None
                         input_option, form = input_line.run(form)
                         ion_to_fix[r_at[0]] = form.upper()
-        self.strucm.add_hydrogens(ion_to_fix, add_charges=opts['add_charges'])
+        self.strucm.add_hydrogens(ion_to_fix, add_charges=opts['add_charges'].upper())
         self.strucm.modified = True
         return False
 # =============================================================================
@@ -1598,12 +1598,14 @@ class StructureChecking():
                 * fix_atoms (str - Fix missing O, OXT backbone atoms):
                     * **all** - Fix all residues
                     * **residue List** - Fix indicated residues
-                * fix_main (str - Fix backbone main chain):
+                * fix_chain (str - Fix backbone main chain):
                     * **all** - All detected breaks
                     * **break list** - Indicated breaks
                 * add_caps (str - Add ACE and NME residues):
                     * **all** - All detected terminals
                     * **residue_list** - Indicated terminals
+                    * **breaks** - Add caps to backbone breaks
+                    * **terms** - Add caps to true terminals
                 * extra_gap (int) - ('0') Recover addiciontal residues from the model to improve match (experimental)
                 * no_recheck (bool) - (False) Do not recheck backbone after fixing 
                 * no_check_clashes (bool) - (False) Do not check for generated clashes
@@ -2027,7 +2029,7 @@ class StructureChecking():
 
         return strucm
     
-    def save_structure(self, output_structure_path, rename_terms=False, split_models=False):
+    def save_structure(self, output_structure_path, rename_terms=False, split_models=False, keep_resnames=False):
         """ StuctureChecking.save_structure
         Saving the current structure in a the output file
         
@@ -2035,6 +2037,7 @@ class StructureChecking():
             output_structure_path (str): Path to saved File
             rename_terms (bool): (False) Rename terminal residues as NXXX, CXXX
             split_models (bool): (False) Save models in separated output files
+            keep_resnames (bool): (False) Keep canonical residue names
         """
         return self._save_structure(output_structure_path, rename_terms=rename_terms, split_models=split_models)
     
@@ -2047,6 +2050,7 @@ class StructureChecking():
             output_structure_path (str): Path to saved File
             rename_terms (bool): (False) Rename terminal residues as NXXX, CXXX
             split_models (bool): (False) Save models in separated output files
+            keep_resnames (bool): (False) Keep canonical residue names        
         """
         input_line = ParamInput(
             "Enter output structure path",
@@ -2059,13 +2063,24 @@ class StructureChecking():
             output_format = self.args['output_format']
         else:
             output_format = os.path.splitext(output_structure_path)[1][1:]
-        
+
         if not split_models:
-            self.strucm.save_structure(output_structure_path, rename_terms=rename_terms, output_format=output_format)
+            self.strucm.save_structure(
+                output_structure_path, 
+                rename_terms=rename_terms, 
+                output_format=output_format, 
+                keep_resnames=self.args['keep_canonical']
+            )
         else:
             for mod in self.strucm.st.get_models():
                 output_path = f'{output_structure_path}_{mod.serial_num}.{output_format}'
-                self.strucm.save_structure(output_path, mod_id = mod.id, rename_terms=rename_terms, output_format=output_format)
+                self.strucm.save_structure(
+                    output_path, 
+                    mod_id = mod.id, 
+                    rename_terms=rename_terms, 
+                    output_format=output_format, 
+                    keep_resnames=self.args['keep_canonical']
+                )
             print(cts.MSGS["SPLIT_MODELS"])
         
         return output_structure_path
